aboutsummaryrefslogtreecommitdiff
path: root/plugins/urlize.c
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/urlize.c')
-rw-r--r--plugins/urlize.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/urlize.c b/plugins/urlize.c
index a3620082..202fa048 100644
--- a/plugins/urlize.c
+++ b/plugins/urlize.c
@@ -10,8 +10,8 @@
* This file contains the urlize plugin
*
* This plugin wraps the text output of another command (plugin) in HTML <A>
* tags, thus displaying the plugin output in as a clickable link in the
* Nagios status screen. The return status is the same as the invoked plugin.
*
*
* This program is free software: you can redistribute it and/or modify
@@ -167,8 +167,8 @@ print_help (void)
printf (COPYRIGHT, copyright, email);
printf ("%s\n", _("This plugin wraps the text output of another command (plugin)"));
- printf ("%s\n", _("in HTML <A> tags, thus displaying the plugin output in as a clickable link in"));
- printf ("%s\n", _("the Nagios status screen. The return status is the same as the invoked plugin."));
+ printf ("%s\n", _("in HTML <A> tags, thus displaying the child plugin's output as a clickable link in"));
+ printf ("%s\n", _("the Nagios status screen. This plugin returns the status of the invoked plugin."));
printf ("\n\n");
@@ -10,8 +10,8 @@
*
* This plugin wraps the text output of another command (plugin) in HTML <A>
-* tags, thus displaying the plugin output in as a clickable link in the
-* Nagios status screen. The return status is the same as the invoked plugin.
+* tags, thus displaying the child plugin's output as a clickable link in the
+* Nagios status screen. This plugin returns the status of the invoked plugin.
*
*